@@ -213,6 +213,15 @@ def check_int(value: str) -> Union[int, None]:
         return None
 
 
+def check_int_max(value: str, max_value: Optional[int] = None) -> Optional[int]:
+    val = check_int(value)
+    if val is None:
+        return None
+    if max_value is not None:
+        return clamp(val, 0, max_value)
+    return clamp_int(val)
+
+
 def int_to_str_ls(int_list: list[int]) -> list[str]:
     """Turn list of ints to list of strings"""
 
@@ -426,7 +435,10 @@ def check_changes(_: Any):
     Args:
         _ (Any): Unused
     """
-    save_path = get_save_path()
+    try:
+        save_path = get_save_path()
+    except Exception:
+        return
     temp_file_path = os.path.join(
         config_manager.get_app_data_folder(), "SAVE_DATA_temp"
     )
@@ -493,10 +505,12 @@ def error_text(text: str):
 
     colored_text(text, base=RED)
 
+
 def is_android() -> bool:
     """Check if the user is on android"""
     return "ANDROID_ROOT" in os.environ
 
+
 def colored_text(
     text: str,
     base: str = WHITE,
@@ -569,14 +583,20 @@ def colored_list(
 def calculate_user_rank(save_stats: dict[str, Any]):
     """Calculate the user rank"""
 
-    user_rank = 10  # blue upgrade base level (1 each)
-    for cat_flag in save_stats["cats"]:
-        if cat_flag == 1:
-            user_rank += 1
-    user_rank += sum(save_stats["cat_upgrades"]["Base"])
-    user_rank += sum(save_stats["cat_upgrades"]["Plus"])
-    user_rank += sum(save_stats["blue_upgrades"]["Base"])
-    user_rank += sum(save_stats["blue_upgrades"]["Plus"])
+    user_rank = 0
+    for cat_id, cat_flag in enumerate(save_stats["cats"]):
+        if cat_flag == 0:
+            continue
+
+        user_rank += save_stats["cat_upgrades"]["Base"][cat_id] + 1
+        user_rank += save_stats["cat_upgrades"]["Plus"][cat_id]
+
+    for skill_id in range(len(save_stats["blue_upgrades"]["Base"])):
+        if skill_id == 1:
+            continue
+        user_rank += save_stats["blue_upgrades"]["Base"][skill_id] + 1
+        user_rank += save_stats["blue_upgrades"]["Plus"][skill_id]
+
     return user_rank
 
 
@@ -620,10 +640,12 @@ def has_tkinter() -> bool:
     try:
         import tkinter  # type: ignore
     except ImportError:
+        colored_text("tkinter is not installed", new=RED)
         return False
     try:
         setup_tk()
     except tkinter.TclError:
+        colored_text("error setting up tkinter", new=RED)
         return False
     return True
 
@@ -675,6 +697,7 @@ def get_cc(save_stats: dict[str, Any]) -> str:
         return "jp"
     return "en"
 
+
 def get_lang(jp: bool) -> str:
     """Get the language code"""
 
