@@ -138,7 +138,10 @@ def get_headers(inquiry_code: str, data: str) -> dict[str, Any]:
 
 
 def handle_request(
-    url: str, data: Union[str, bytes, None], headers: dict[str, Any], is_get: bool = False
+    url: str,
+    data: Union[str, bytes, None],
+    headers: dict[str, Any],
+    is_get: bool = False,
 ) -> Union[dict[str, Any], None]:
     """Handle a request."""
 
@@ -279,6 +282,68 @@ def download_save(
     return response.content
 
 
+def upload_save_data_body_v2(
+    save_data: bytes,
+    save_key_data: dict[str, Any],
+) -> tuple[bytes, bytes]:
+    """Returns the body for the upload save data request
+
+    Args:
+        save_data (bytes): Save data
+        save_key_data (dict[str, Any]): Save key data
+
+    Returns:
+        tuple[bytes, bytes]: Body and boundary
+    """
+    boundary = f"__-----------------------{random_digit_string(9)}-2147483648".encode(
+        "utf-8"
+    )
+    body = b""
+    body += b"--" + boundary + b"\r\n"
+    body += b'Content-Disposition: form-data; name="key"\r\n'
+    body += b"Content-Type: text/plain\r\n"
+    body += b"\r\n"
+    body += save_key_data["key"].encode("utf-8") + b"\r\n"
+    body += b"--" + boundary + b"\r\n"
+    body += b'Content-Disposition: form-data; name="policy"\r\n'
+    body += b"Content-Type: text/plain\r\n"
+    body += b"\r\n"
+    body += save_key_data["policy"].encode("utf-8") + b"\r\n"
+    body += b"--" + boundary + b"\r\n"
+    body += b'Content-Disposition: form-data; name="x-amz-signature"\r\n'
+    body += b"Content-Type: text/plain\r\n"
+    body += b"\r\n"
+    body += save_key_data["x-amz-signature"].encode("utf-8") + b"\r\n"
+    body += b"--" + boundary + b"\r\n"
+    body += b'Content-Disposition: form-data; name="x-amz-credential"\r\n'
+    body += b"Content-Type: text/plain\r\n"
+    body += b"\r\n"
+    body += save_key_data["x-amz-credential"].encode("utf-8") + b"\r\n"
+    body += b"--" + boundary + b"\r\n"
+    body += b'Content-Disposition: form-data; name="x-amz-algorithm"\r\n'
+    body += b"Content-Type: text/plain\r\n"
+    body += b"\r\n"
+    body += save_key_data["x-amz-algorithm"].encode("utf-8") + b"\r\n"
+    body += b"--" + boundary + b"\r\n"
+    body += b'Content-Disposition: form-data; name="x-amz-date"\r\n'
+    body += b"Content-Type: text/plain\r\n"
+    body += b"\r\n"
+    body += save_key_data["x-amz-date"].encode("utf-8") + b"\r\n"
+    body += b"--" + boundary + b"\r\n"
+    body += b'Content-Disposition: form-data; name="x-amz-security-token"\r\n'
+    body += b"Content-Type: text/plain\r\n"
+    body += b"\r\n"
+    body += save_key_data["x-amz-security-token"].encode("utf-8") + b"\r\n"
+    body += b"--" + boundary + b"\r\n"
+    body += b'Content-Disposition: form-data; name="file"; filename="file.sav"\r\n'
+    body += b"Content-Type: application/octet-stream\r\n"
+    body += b"\r\n"
+    body += save_data + b"\r\n"
+    body += b"--" + boundary + b"--\r\n"
+
+    return body, boundary
+
+
 def upload_save_data_body(
     managed_item_details: dict[str, Any],
     inquiry_code: str,
@@ -325,45 +390,148 @@ def upload_save_data(
     if not config_manager.get_config_value_category("SERVER", "UPLOAD_METADATA"):
         items = []
     save_key = get_save_key(token)
-    metadata = create_backup_metadata(items, play_time, inquiry_code, user_rank, save_key)
+    metadata = create_backup_metadata(
+        items, play_time, inquiry_code, user_rank, save_key
+    )
     body, headers = upload_save_data_body(metadata, inquiry_code, token, save_data)
 
     url = get_nyanko_save_url() + "/v1/transfers"
     return handle_request(url, body, headers)
 
-def get_save_key(token: str):
-    """Gets the save key for the given token"""
 
-    url = get_nyanko_save_url() + "/v2/save/key?nonce=" + random_hex_string(32)
-    headers = {
-        "accept-encoding": "gzip",
-        "connection": "keep-alive",
-        "authorization": "Bearer " + token,
-        "nyanko-timestamp" : str(get_current_time()),
-        "user-agent": "Dalvik/2.1.0 (Linux; U; Android 9; SM-G955F Build/N2G48B)",
-    }
-    payload = handle_request(url, None, headers, True)
-    if payload is not None:
-        if "key" in payload:
-            return payload["key"]
-    helper.colored_text("Error getting save key", helper.RED)
-    return None
-
-def upload_metadata(
+def upload_save_data_v2(
     token: str,
     inquiry_code: str,
     save_data: bytes,
     play_time: int,
     items: list[managed_item.ManagedItem],
     user_rank: int,
+):
+    """Uploads the save data for the given token, inquiry_code and save_data"""
+
+    if not config_manager.get_config_value_category("SERVER", "UPLOAD_METADATA"):
+        items = []
+    save_key_data = get_save_key_data(token)
+    if save_key_data is None:
+        return None
+    metadata = create_backup_metadata(
+        items, play_time, inquiry_code, user_rank, save_key_data["key"]
+    )
+    body, boundary = upload_save_data_body_v2(save_data, save_key_data)
+
+    url = "https://nyanko-service-data-prd.s3.amazonaws.com/"
+    headers = {
+        "accept-encoding": "gzip",
+        "connection": "keep-alive",
+        "content-type": "multipart/form-data; boundary=" + boundary.decode("utf-8"),
+        "user-agent": "Dalvik/2.1.0 (Linux; U; Android 9; SM-G955F Build/N2G48B)",
+    }
+
+    response = requests.post(url, data=body, headers=headers)
+    if response.status_code != 204:
+        return None
+
+    url_2 = get_nyanko_save_url() + "/v2/transfers"
+    meta_data = json.dumps(metadata).replace(" ", "")
+    headers_2 = get_headers(inquiry_code, meta_data)
+    headers_2["authorization"] = "Bearer " + token
+
+    return handle_request(url_2, meta_data, headers_2)
+
+
+def upload_metadata_v2(
+    token: str,
+    inquiry_code: str,
+    save_data: bytes,
+    play_time: int,
+    items: list[managed_item.ManagedItem],
+    user_rank: int,
+):
+    """Uploads the save data for the given token, inquiry_code and save_data"""
+
+    if not config_manager.get_config_value_category("SERVER", "UPLOAD_METADATA"):
+        items = []
+    save_key_data = get_save_key_data(token)
+    if save_key_data is None:
+        return None
+    metadata = create_backup_metadata(
+        items, play_time, inquiry_code, user_rank, save_key_data["key"]
+    )
+    body, boundary = upload_save_data_body_v2(save_data, save_key_data)
+
+    url = "https://nyanko-service-data-prd.s3.amazonaws.com/"
+    headers = {
+        "accept-encoding": "gzip",
+        "connection": "keep-alive",
+        "content-type": "multipart/form-data; boundary=" + boundary.decode("utf-8"),
+        "user-agent": "Dalvik/2.1.0 (Linux; U; Android 9; SM-G955F Build/N2G48B)",
+    }
+
+    response = requests.post(url, data=body, headers=headers)
+    if response.status_code != 204:
+        return None
+
+    url_2 = get_nyanko_save_url() + "/v2/backups"
+    meta_data = json.dumps(metadata).replace(" ", "")
+    headers_2 = get_headers(inquiry_code, meta_data)
+    headers_2["authorization"] = "Bearer " + token
+
+    return handle_request(url_2, meta_data, headers_2)
+
+
+def get_save_key_data(token: str) -> Optional[dict[str, Any]]:
+    """Gets the save key for the given token"""
+
+    url = get_nyanko_save_url() + "/v2/save/key?nonce=" + random_hex_string(32)
+    headers = {
+        "accept-encoding": "gzip",
+        "connection": "keep-alive",
+        "authorization": "Bearer " + token,
+        "nyanko-timestamp": str(get_current_time()),
+        "user-agent": "Dalvik/2.1.0 (Linux; U; Android 9; SM-G955F Build/N2G48B)",
+    }
+    payload = handle_request(url, None, headers, True)
+    if payload is not None:
+        return payload
+    helper.colored_text("Error getting save key", helper.RED)
+    return None
+
+
+def get_save_key(token: str) -> Optional[str]:
+    """Gets the save key for the given token
+
+    Args:
+        token (str): The token to get the save key for
+
+    Returns:
+        Optional[str]: The save key or None if it could not be retrieved
+    """
+    data = get_save_key_data(token)
+    if data is not None:
+        return data["key"]
+    return None
+
+
+def upload_metadata(
+    token: str,
+    inquiry_code: str,
+    play_time: int,
+    items: list[managed_item.ManagedItem],
+    user_rank: int,
 ):
     """Uploads the metadata for the given token, inquiry_code and save_data"""
     save_key = get_save_key(token)
-    metadata = create_backup_metadata(items, play_time, inquiry_code, user_rank, save_key)
-    body, headers = upload_save_data_body(metadata, inquiry_code, token, save_data)
+    metadata = create_backup_metadata(
+        items, play_time, inquiry_code, user_rank, save_key
+    )
 
-    url = get_nyanko_save_url() + "/v1/backups"
-    return handle_request(url, body, headers)
+    managed_item_details_str = json.dumps(metadata)
+    managed_item_details_str = managed_item_details_str.replace(" ", "")
+    headers = get_headers(inquiry_code, managed_item_details_str)
+    headers["authorization"] = "Bearer " + token
+
+    url = get_nyanko_save_url() + "/v2/backups"
+    return handle_request(url, managed_item_details_str, headers)
 
 
 def get_nyanko_backups_url() -> str:
@@ -469,7 +637,10 @@ def check_gen_password(
 
 
 def prepare_upload(
-    save_stats: dict[str, Any], path: str, print_text: bool = True, managed_items: Optional[list[managed_item.ManagedItem]] = None
+    save_stats: dict[str, Any],
+    path: str,
+    print_text: bool = True,
+    managed_items: Optional[list[managed_item.ManagedItem]] = None,
 ) -> Optional[tuple[str, Any, bytes, int, list[managed_item.ManagedItem]]]:
     """Handles the pre-upload of the save data"""
 
@@ -513,7 +684,7 @@ def upload_handler(
     token, inquiry_code, save_data, playtime, managed_items = data
 
     helper.colored_text("Uploading save data...", helper.GREEN)
-    upload_data = upload_save_data(
+    upload_data = upload_save_data_v2(
         token,
         inquiry_code,
         save_data,
@@ -521,6 +692,14 @@ def upload_handler(
         managed_items,
         helper.calculate_user_rank(save_stats),
     )
+    # upload_data = upload_save_data(
+    #    token,
+    #    inquiry_code,
+    #    save_data,
+    #    playtime,
+    #    managed_items,
+    #    helper.calculate_user_rank(save_stats),
+    # )
 
     helper.colored_text(
         "After entering these codes in game, you may get a ban message when pressing play. If you do, just press play again and it should go away.\nPress enter to get your codes...",
@@ -541,7 +720,7 @@ def meta_data_upload_handler(
     token, inquiry_code, save_data, playtime, managed_items = data
 
     helper.colored_text("Uploading meta data...", helper.GREEN)
-    upload_data = upload_metadata(
+    upload_data = upload_metadata_v2(
         token,
         inquiry_code,
         save_data,
@@ -552,6 +731,7 @@ def meta_data_upload_handler(
 
     return upload_data, save_stats
 
+
 def test_is_save_data(save_data: bytes) -> bool:
     """Test if the save data is a valid save data"""
 
@@ -562,6 +742,7 @@ def test_is_save_data(save_data: bytes) -> bool:
     else:
         return False
 
+
 def download_handler() -> Optional[str]:
     """Handles the download of the save data"""
 
